<?php include_once("_header.php"); ?>
  <tr>

    <td align="right" valign="top" class="section"><b>Hosters&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block">SourceForge is the primary hoster of the <i>ttyrpld</i>
      project. It runs the File Release System, Support Trackers, Forum, News
      and Mailing Lists systems for us.</p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top"
    class="section"><b>Trackers&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block">SourceForge Links: <a
      href="http://sourceforge.net/projects/ttyrpld/"
      target="_blank">[Overview]</a> <a
      href="http://sourceforge.net/tracker/?group_id=120202&atid=686264"
      target="_blank">[Support]</a> <a
      href="http://sourceforge.net/tracker/?group_id=120202&amp;atid=686263"
      target="_blank">[Bugs]</a> <a
      href="http://sourceforge.net/tracker/?group_id=120202&atid=686265"
      target="_blank">[Patches]</a> <a
      href="http://sourceforge.net/tracker/?group_id=120202&atid=686266"
      target="_blank">[Feature Requests]</a></p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top" class="section"><b>Mailing
    lists&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block">Another option of getting in contact: <a
      href="http://sourceforge.net/mail/?group_id=120202"
      target="_blank">Mailing lists</a>.</p>

      <p class="block">There is currently one list set up, <a
      href="http://lists.sourceforge.net/mailman/listinfo/ttyrpld-user"
      target="_blank">ttyrpld-user</a> which is about everything around
      <i>ttyrpld</i>.</p>

    </td>
  </tr>
<?php include_once("_footer.php"); ?>
